#!/usr/bin/env python

from flask import Flask, send_file, Response
import base64
import os
import subprocess
from datetime import datetime
from openai import OpenAI

class GameInterface:
    def click(self, x, y):
        subprocess.run(['xdotool', 'mousemove', x, y, 'click', '1'])

    def screenshot(self):
        scrot = subprocess.run(['scrot', '-'], capture_output = True)
        return scrot.stdout

app = Flask(__name__)
openai_client = OpenAI(api_key = os.environ['OPENAI_KEY'])
game = GameInterface()

@app.route('/')
def index():
    return send_file('index.html', mimetype='text/html')

@app.route('/screenshot')
def screenshot():
    return Response(game.screenshot(), mimetype='image/png')

@app.route('/click/<int:x>/<int:y>')
def click(x, y):
    game.click(str(x), str(y))
    return f'Click performed at position ({x}, {y})'

@app.route('/ask-for-next-move')
def nextmove():
    screenshot = game.screenshot()
    screenshot64 = base64.b64encode(screenshot).decode('utf-8')

    response = openai_client.chat.completions.create(
        model="gpt-4o-mini",
        messages=[ {
            "role": "user",
            "content": [
                {"type": "text", "text": "we're playing Into the Breach. Describe the state of the board. Then tell me the best moves for our mechs to make."},
                {"type": "image_url", "image_url": { "url": f"data:image/png;base64,{screenshot64}", }, },
            ],
        } ]
    )
    return response.choices[0].message.content


if __name__ == '__main__':
    app.run(debug=True, host='0.0.0.0', port=5000)
